@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
 # (c) Satelligence, see LICENSE.rst.
-"""Common logger and monitoring utils
+"""Common logging and monitoring utils
 """
 import os
 import socket
 
 from google.cloud.logging._helpers import retrieve_metadata_server  # pylint: disable=protected-access
 from google.cloud.logging.resource import Resource as LoggingResource
-from google.cloud import monitoring
+from google.cloud import monitoring_v3
 
 
 
 PROJECT_ID = retrieve_metadata_server('project/project-id')
+if not PROJECT_ID:
+    PROJECT_ID = os.environ.get('GOOGLE_PROJECT_ID', '')
 CLUSTER_NAME = retrieve_metadata_server('instance/attributes/cluster-name')
 LOCATION = retrieve_metadata_server('instance/attributes/cluster-location')
 NAMESPACE_NAME = os.environ.get('KUBERNETES_NAMESPACE', '')
@@ -19,7 +21,7 @@ CONTAINER_NAME = os.environ.get('KUBERNETES_CONTAINER_NAME', '')
 NODE_NAME = os.environ.get('KUBERNETES_NODE_NAME', '')
 POD_NAME = socket.gethostname()
 
-MONITORING_CLIENT = monitoring.MetricServiceClient()
+MONITORING_CLIENT = monitoring_v3.MetricServiceClient()
 
 
 def labels_dict():
@@ -32,6 +34,16 @@ def labels_dict():
         'container_name': CONTAINER_NAME,
     }
 
+
+def stringify_label(label):
+    # prettier printing for things like classes and functions
+    label_str = (
+        '{}.{}'.format(label.__module__, label.__name__)
+        if hasattr(label, '__module__') and hasattr(label, '__name__')
+        else str(label)
+    )
+    return label_str
+
 def logging_k8s_container():
     if PROJECT_ID and CLUSTER_NAME:
         return LoggingResource(
